==========
Grimsel
==========

**G**\ene\ **R**\al **I**\ntegrated **M**\odeling environment for the **S**\upply of **E**\lectricity and **L**\ow-temperature heat

============
Installation
============

``pip install grimsel``

`<https://pypi.org/project/Grimsel/>`_

=============
Documentation
=============

`<https://grimsel.readthedocs.io/>`_

============
Publications
============
  * \M. C. Soini *et al.*, Does bulk electricity storage assist wind and solar in replacing dispatchable power production?, Energy Economics, `<https://doi.org/10.1016/j.eneco.2019.104495>`_. 
  * \A. Rinaldi *et al.*, Optimised allocation of PV and storage capacity among different consumer types and urban settings: A prospective analysis for Switzerland, Journal of Cleaner Production, `<https://doi.org/10.1016/j.jclepro.2020.120762>`_. 
  * \M. C. Soini *et al.*, Impact of prosumer battery operation on the cost of power supply, Journal of Energy Storage `<https://doi.org/10.1016/j.est.2020.101323>`_. 

